[![Tests](https://github.com/redcodeworks/hypermodern/workflows/Tests/badge.svg)](https://github.com/redcodeworks/hypermodern/actions?workflow=Tests)
[![Codecov](https://codecov.io/gh/redcodeworks/hypermodern/branch/main/graph/badge.svg)](https://codecov.io/gh/redcodeworks/hypermodern)
[![PyPI](https://img.shields.io/pypi/v/hypermodern.svg)](https://pypi.org/project/hypermodern/)
